@@ -182,6 +182,8 @@ func createTargetConfigController(c TargetConfigController, recorder events.Reco
 		"v4.1.0/kube-controller-manager/leader-election-rolebinding.yaml",
 		"v4.1.0/kube-controller-manager/leader-election-cluster-policy-controller-role.yaml",
 		"v4.1.0/kube-controller-manager/leader-election-cluster-policy-controller-rolebinding.yaml",
+		"v4.1.0/kube-controller-manager/leader-election-kube-controller-manager-role-kube-system.yaml",
+		"v4.1.0/kube-controller-manager/leader-election-kube-controller-manager-rolebinding-kube-system.yaml",
 		"v4.1.0/kube-controller-manager/svc.yaml",
 		"v4.1.0/kube-controller-manager/sa.yaml",
 	)
